module Recurify
  module RuleValidation # :nodoc:
    MIN_INTERVAL = 1
    MIN_COUNT    = 1

    private

    # @return [void]
    def validate!
      validate_frequency!
      validate_interval!
      validate_count!
    end

    # @raise [InvalidRuleFrequency]
    # @return [void]
    def validate_frequency!
      return if Rule::SUPPORTED_FREQUENCIES.include?(frequency)
      fail InvalidRuleFrequency, "'#{frequency}' is not supported"
    end

    # @raise [InvalidRuleInterval]
    # @return [void]
    def validate_interval!
      return if interval >= MIN_INTERVAL
      fail InvalidRuleInterval, "'#{interval}' is not supported"
    end

    # @raise [InvalidRuleCount]
    # @return [void]
    def validate_count!
      return if count.nil? || count >= MIN_COUNT
      fail InvalidRuleCount, "'#{count}' is not supported"
    end
  end
end
